@@ -1,77 +1,40 @@
 import _isNil from "lodash/isNil";
 import _assign from "lodash/assign";
-import { Helpers, LabelHelpers, Data, Domain, Scale, Collection } from "victory-core";
+import { Helpers, LabelHelpers, Data, Domain, Scale } from "victory-core";
 
-var getDataWithBaseline = function (props, scale) {
+var getCalculatedValues = function (props) {
   var data = Data.getData(props);
 
   if (data.length < 2) {
     data = [];
   }
 
-  var getDefaultMin = function (axis) {
-    var defaultZero = Scale.getType(scale[axis]) === "log" ? 1 / Number.MAX_SAFE_INTEGER : 0;
-    var domain = scale[axis].domain();
-    var minY = Collection.getMinValue(domain);
-    var maxY = Collection.getMaxValue(domain);
-    var defaultMin = defaultZero;
-
-    if (minY < 0 && maxY <= 0) {
-      defaultMin = maxY;
-    } else if (minY >= 0 && maxY > 0) {
-      defaultMin = minY;
-    }
-
-    return Collection.containsDates(domain) ? new Date(defaultMin) : defaultMin;
-  };
-
-  return data.map(function (datum) {
-    var _y1 = datum._y1 !== undefined ? datum._y1 : datum._y;
-
-    var _y0 = datum._y0 !== undefined ? datum._y0 : getDefaultMin("y");
-
-    var _x1 = datum._x1 !== undefined ? datum._x1 : datum._x;
-
-    var _x0 = datum._x0 !== undefined ? datum._x0 : getDefaultMin("x");
-
-    return _assign({}, datum, {
-      _y0: _y0,
-      _y1: _y1,
-      _x0: _x0,
-      _x1: _x1
-    });
-  });
-};
-
-var getCalculatedValues = function (props) {
-  var polar = props.polar;
-  var defaultStyles = Helpers.getDefaultStyles(props, "area");
-  var style = Helpers.getStyles(props.style, defaultStyles);
   var range = {
     x: Helpers.getRange(props, "x"),
     y: Helpers.getRange(props, "y")
   };
   var domain = {
-    x: Domain.getDomainWithZero(props, "x"),
-    y: Domain.getDomainWithZero(props, "y")
+    x: Domain.getDomain(props, "x"),
+    y: Domain.getDomain(props, "y")
   };
   var scale = {
     x: Scale.getBaseScale(props, "x").domain(domain.x).range(props.horizontal ? range.y : range.x),
     y: Scale.getBaseScale(props, "y").domain(domain.y).range(props.horizontal ? range.x : range.y)
   };
-  var origin = polar ? props.origin || Helpers.getPolarOrigin(props) : undefined;
-  var data = getDataWithBaseline(props, scale);
+  var origin = props.polar ? props.origin || Helpers.getPolarOrigin(props) : undefined;
+  var defaultStyles = Helpers.getDefaultStyles(props, "line");
+  var style = Helpers.getStyles(props.style, defaultStyles);
   return {
-    style: style,
+    domain: domain,
     data: data,
     scale: scale,
-    domain: domain,
+    style: style,
     origin: origin
   };
 };
 
 var getBaseProps = function (props, fallbackProps) {
-  var modifiedProps = Helpers.modifyProps(props, fallbackProps, "area");
+  var modifiedProps = Helpers.modifyProps(props, fallbackProps, "line");
   props = _assign({}, modifiedProps, getCalculatedValues(modifiedProps));
   var _props = props,
       data = _props.data,
@@ -95,17 +58,16 @@ var getBaseProps = function (props, fallbackProps) {
   var initialChildProps = {
     parent: {
       style: style.parent,
-      width: width,
-      height: height,
       scale: scale,
       data: data,
+      height: height,
+      width: width,
+      name: name,
       domain: domain,
       standalone: standalone,
-      theme: theme,
       polar: polar,
       origin: origin,
       padding: padding,
-      name: name,
       horizontal: horizontal
     },
     all: {
@@ -117,7 +79,8 @@ var getBaseProps = function (props, fallbackProps) {
         data: data,
         interpolation: interpolation,
         groupComponent: groupComponent,
-        style: style.data
+        style: style.data,
+        theme: theme
       }
     }
   };
@@ -135,4 +98,4 @@ var getBaseProps = function (props, fallbackProps) {
   }, initialChildProps);
 };
 
-export { getBaseProps, getDataWithBaseline };
\ No newline at end of file
+export { getBaseProps };
\ No newline at end of file
